==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/outputs/AzureRecoveryServiceVaultProtectionIntentResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Azure Recovery Services Vault specific protection intent item.
 * @property backupManagementType Type of backup management for the backed up item.
 * @property itemId ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
 * @property policyId ID of the backup policy with which this item is backed up.
 * @property protectionIntentItemType backup protectionIntent type.
 * Expected value is 'RecoveryServiceVaultItem'.
 * @property protectionState Backup state of this backup item.
 * @property sourceResourceId ARM ID of the resource to be backed up.
 */
public data class AzureRecoveryServiceVaultProtectionIntentResponse(
    public val backupManagementType: String? = null,
    public val itemId: String? = null,
    public val policyId: String? = null,
    public val protectionIntentItemType: String,
    public val protectionState: String? = null,
    public val sourceResourceId: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.outputs.AzureRecoveryServiceVaultProtectionIntentResponse):
            AzureRecoveryServiceVaultProtectionIntentResponse =
            AzureRecoveryServiceVaultProtectionIntentResponse(
                backupManagementType = javaType.backupManagementType().map({ args0 -> args0 }).orElse(null),
                itemId = javaType.itemId().map({ args0 -> args0 }).orElse(null),
                policyId = javaType.policyId().map({ args0 -> args0 }).orElse(null),
                protectionIntentItemType = javaType.protectionIntentItemType(),
                protectionState = javaType.protectionState().map({ args0 -> args0 }).orElse(null),
                sourceResourceId = javaType.sourceResourceId().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/outputs/AzureRecoveryServiceVaultProtectionIntentResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Azure Recovery Services Vault specific protection intent item.
 * @property backupManagementType Type of backup management for the backed up item.
 * @property itemId ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
 * @property policyId ID of the backup policy with which this item is backed up.
 * @property protectionIntentItemType backup protectionIntent type.
 * Expected value is 'RecoveryServiceVaultItem'.
 * @property protectionState Backup state of this backup item.
 * @property sourceResourceId ARM ID of the resource to be backed up.
 */
public data class AzureRecoveryServiceVaultProtectionIntentResponse(
    public val backupManagementType: String? = null,
    public val itemId: String? = null,
    public val policyId: String? = null,
    public val protectionIntentItemType: String,
    public val protectionState: String? = null,
    public val sourceResourceId: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.outputs.AzureRecoveryServiceVaultProtectionIntentResponse): AzureRecoveryServiceVaultProtectionIntentResponse =
            AzureRecoveryServiceVaultProtectionIntentResponse(
                backupManagementType = javaType.backupManagementType().map({ args0 -> args0 }).orElse(null),
                itemId = javaType.itemId().map({ args0 -> args0 }).orElse(null),
                policyId = javaType.policyId().map({ args0 -> args0 }).orElse(null),
                protectionIntentItemType = javaType.protectionIntentItemType(),
                protectionState = javaType.protectionState().map({ args0 -> args0 }).orElse(null),
                sourceResourceId = javaType.sourceResourceId().map({ args0 -> args0 }).orElse(null),
            )
    }
}
